@@ -1,27 +1,39 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4: */
-//
-// +----------------------------------------------------------------------+
-// | PHP Version 4                                                        |
-// +----------------------------------------------------------------------+
-// | Copyright (c) 1997-2002 The PHP Group                                |
-// +----------------------------------------------------------------------+
-// | This source file is subject to version 2.02 of the PHP license,      |
-// | that is bundled with this package in the file LICENSE, and is        |
-// | available at through the world-wide-web at                           |
-// | http://www.php.net/license/3_0.txt.                                  |
-// | If you did not receive a copy of the PHP license and are unable to   |
-// | obtain it through the world-wide-web, please send a note to          |
-// | license@php.net so we can mail you a copy immediately.               |
-// +----------------------------------------------------------------------+
-// | Authors: Harry Fuecks <hfuecks@phppatterns.com>                      |
-// +----------------------------------------------------------------------+
-//
-// $Id: Weekdays.php 2283 2009-09-04 14:46:22Z fishbone $
-//
+
 /**
- * @package Calendar
- * @version $Id: Weekdays.php 2283 2009-09-04 14:46:22Z fishbone $
+ * Contains the Calendar_Month_Weekdays class
+ *
+ * PHP versions 4 and 5
+ *
+ * LICENSE: Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. The name of the author may not be used to endorse or promote products
+ *    derived from this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
+ * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE FREEBSD PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY
+ * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * @category  Date and Time
+ * @package   Calendar
+ * @author    Harry Fuecks <hfuecks@phppatterns.com>
+ * @copyright 2003-2007 Harry Fuecks
+ * @license   http://www.debian.org/misc/bsd.license  BSD License (3 Clause)
+ * @version   CVS: $Id: Weekdays.php 4940 2012-06-06 02:20:28Z fishbone $
+ * @link      http://pear.php.net/package/Calendar
  */
 
 /**
@@ -46,7 +58,7 @@ require_once CALENDAR_ROOT.'Month.php';
  * Represents a Month and builds Days in tabular form<br>
  * <code>
  * require_once 'Calendar/Month/Weekdays.php';
- * $Month = & new Calendar_Month_Weekdays(2003, 10); // Oct 2003
+ * $Month = new Calendar_Month_Weekdays(2003, 10); // Oct 2003
  * $Month->build(); // Build Calendar_Day objects
  * while ($Day = & $Month->fetch()) {
  *     if ($Day->isFirst()) {
@@ -62,8 +74,14 @@ require_once CALENDAR_ROOT.'Month.php';
  *     }
  * }
  * </code>
- * @package Calendar
- * @access public
+ *
+ * @category  Date and Time
+ * @package   Calendar
+ * @author    Harry Fuecks <hfuecks@phppatterns.com>
+ * @copyright 2003-2007 Harry Fuecks
+ * @license   http://www.debian.org/misc/bsd.license  BSD License (3 Clause)
+ * @link      http://pear.php.net/package/Calendar
+ * @access    public
  */
 class Calendar_Month_Weekdays extends Calendar_Month
 {
@@ -83,30 +101,34 @@ class Calendar_Month_Weekdays extends Calendar_Month
 
     /**
      * Constructs Calendar_Month_Weekdays
-     * @param int year e.g. 2003
-     * @param int month e.g. 5
-     * @param int (optional) first day of week (e.g. 0 for Sunday, 2 for Tuesday etc.)
+     *
+     * @param int $y        year e.g. 2003
+     * @param int $m        month e.g. 5
+     * @param int $firstDay (optional) first day of week (e.g. 0 for Sunday, 2 for Tuesday etc.)
+     *
      * @access public
      */
     function Calendar_Month_Weekdays($y, $m, $firstDay=null)
     {
-        Calendar_Month::Calendar_Month($y, $m, $firstDay);
+        parent::Calendar_Month($y, $m, $firstDay);
     }
 
     /**
      * Builds Day objects in tabular form, to allow display of calendar month
      * with empty cells if the first day of the week does not fall on the first
      * day of the month.
+     *
+     * @param array $sDates (optional) Calendar_Day objects representing selected dates
+     *
+     * @return boolean
+     * @access public
      * @see Calendar_Day::isEmpty()
      * @see Calendar_Day_Base::isFirst()
      * @see Calendar_Day_Base::isLast()
-     * @param array (optional) Calendar_Day objects representing selected dates
-     * @return boolean
-     * @access public
      */
-    function build($sDates=array())
+    function build($sDates = array())
     {
-        require_once CALENDAR_ROOT.'Table/Helper.php';
+        include_once CALENDAR_ROOT.'Table/Helper.php';
         $this->tableHelper = new Calendar_Table_Helper($this, $this->firstDay);
         Calendar_Month::build($sDates);
         $this->buildEmptyDaysBefore();
@@ -118,6 +140,7 @@ class Calendar_Month_Weekdays extends Calendar_Month
 
     /**
      * Prepends empty days before the real days in the month
+     *
      * @return void
      * @access private
      */
@@ -138,12 +161,13 @@ class Calendar_Month_Weekdays extends Calendar_Month
 
     /**
      * Shifts the array of children forward, if necessary
+     *
      * @return void
      * @access private
      */
     function shiftDays()
     {
-        if (isset ($this->children[0])) {
+        if (isset($this->children[0])) {
             array_unshift($this->children, null);
             unset($this->children[0]);
         }
@@ -151,14 +175,15 @@ class Calendar_Month_Weekdays extends Calendar_Month
 
     /**
      * Appends empty days after the real days in the month
+     *
      * @return void
      * @access private
      */
     function buildEmptyDaysAfter()
     {
         $eAfter = $this->tableHelper->getEmptyDaysAfter();
-        $sDOM = $this->tableHelper->getNumTableDaysInMonth();
-        for ($i = 1; $i <= $sDOM-$eAfter; $i++) {
+        $sDOM   = $this->tableHelper->getNumTableDaysInMonth();
+        for ($i=1; $i <= $sDOM-$eAfter; $i++) {
             $Day = new Calendar_Day($this->year, $this->month+1, $i);
             $Day->setEmpty();
             $Day->adjust();
@@ -169,12 +194,13 @@ class Calendar_Month_Weekdays extends Calendar_Month
     /**
      * Sets the "markers" for the beginning and of a of week, in the
      * built Calendar_Day children
+     *
      * @return void
      * @access private
      */
     function setWeekMarkers()
     {
-        $dIW  = $this->cE->getDaysInWeek(
+        $dIW = $this->cE->getDaysInWeek(
             $this->thisYear(),
             $this->thisMonth(),
             $this->thisDay()
